==> react-molecule-tabs-2.31.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { Children, cloneElement, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { TYPES, VARIANTS } from './config.js';
import MoleculeTab from './components/MoleculeTab.js';
import MoleculeTabs from './components/MoleculeTabs.js';
import { jsx as _jsx } from "react/jsx-runtime";

var MoleculeTabsWithStateActive = function MoleculeTabsWithStateActive(props) {
  var _useState = useState(null),
      activeTab = _useState[0],
      setActiveTab = _useState[1];

  var children = props.children,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange;
  useEffect(function () {
    Children.forEach(children, function (child, index) {
      if (child) {
        var active = child.props.active;
        if (active) setActiveTab(index + 1);
      }
    });
  }, []); // eslint-disable-line

  var extendedChildren = function extendedChildren() {
    return Children.toArray(children).filter(Boolean).map(function (child, index) {
      var numTab = index + 1;
      var active = activeTab === numTab;
      return /*#__PURE__*/cloneElement(child, {
        active: active
      });
    });
  };

  var handleChange = function handleChange(e, _ref) {
    var numTab = _ref.numTab;
    setActiveTab(numTab);
    onChange(e, {
      numTab: numTab
    });
  };

  return /*#__PURE__*/_jsx(MoleculeTabs, _extends({}, props, {
    onChange: handleChange,
    children: extendedChildren()
  }));
};

MoleculeTabsWithStateActive.displayName = 'MoleculeTabsWithStateActive';
export { MoleculeTab, MoleculeTabs, MoleculeTabsWithStateActive, TYPES as moleculeTabsTypes, VARIANTS as moleculeTabsVariants };
export default MoleculeTabsWithStateActive;

==> react-molecule-tabs-2.34.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["children", "onChange"];
import { Children, cloneElement, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { TYPES, VARIANTS } from './config.js';
import MoleculeTab from './components/MoleculeTab.js';
import MoleculeTabs from './components/MoleculeTabs.js';
import { jsx as _jsx } from "react/jsx-runtime";

var MoleculeTabsWithStateActive = function MoleculeTabsWithStateActive(_ref) {
  var children = _ref.children,
      onChange = _ref.onChange,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(null),
      activeTab = _useState[0],
      setActiveTab = _useState[1];

  useEffect(function () {
    Children.forEach(children, function (child, index) {
      if (child) {
        var active = child.props.active;
        if (active) setActiveTab(index + 1);
      }
    });
  }, []); // eslint-disable-line

  var extendedChildren = function extendedChildren() {
    return Children.toArray(children).filter(Boolean).map(function (child, index) {
      var numTab = index + 1;
      var active = activeTab === numTab;
      return /*#__PURE__*/cloneElement(child, {
        active: active
      });
    });
  };

  var handleChange = function handleChange(e, _ref2) {
    var numTab = _ref2.numTab;
    setActiveTab(numTab);
    typeof onChange === 'function' && onChange(e, {
      numTab: numTab
    });
  };

  return /*#__PURE__*/_jsx(MoleculeTabs, _extends({}, props, {
    onChange: handleChange,
    children: extendedChildren()
  }));
};

MoleculeTabsWithStateActive.displayName = 'MoleculeTabsWithStateActive';
export { MoleculeTab, MoleculeTabs, MoleculeTabsWithStateActive, TYPES as moleculeTabsTypes, VARIANTS as moleculeTabsVariants };
export default MoleculeTabsWithStateActive;
